@@ -62,13 +62,7 @@ APPLE_HOMEKIT_START_BYTE: Final = 0x06  # homekit_controller
 APPLE_DEVICE_ID_START_BYTE: Final = 0x10  # bluetooth_le_tracker
 APPLE_HOMEKIT_NOTIFY_START_BYTE: Final = 0x11  # homekit_controller
 APPLE_FINDMY_START_BYTE: Final = 0x12  # FindMy network advertisements
-APPLE_START_BYTES_WANTED: Final = {
-    APPLE_IBEACON_START_BYTE,
-    APPLE_HOMEKIT_START_BYTE,
-    APPLE_HOMEKIT_NOTIFY_START_BYTE,
-    APPLE_DEVICE_ID_START_BYTE,
-    APPLE_FINDMY_START_BYTE,
-}
+
 
 _str = str
 
@@ -132,10 +126,10 @@ class BluetoothManager:
         "_recovery_lock",
         "_scanner_registration_callbacks",
         "_sources",
+        "_subclass_discover_info",
         "_unavailable_callbacks",
         "shutdown",
         "slot_manager",
-        "_subclass_discover_info",
     )
 
     def __init__(
@@ -451,13 +445,12 @@ class BluetoothManager:
 
     def _prefer_previous_adv_from_different_source(
         self,
-        address: _str,
         old: BluetoothServiceInfoBleak,
         new: BluetoothServiceInfoBleak,
     ) -> bool:
         """Prefer previous advertisement from a different source if it is better."""
         if stale_seconds := self._intervals.get(
-            address, self._fallback_intervals.get(address, 0)
+            new.address, self._fallback_intervals.get(new.address, 0)
         ):
             stale_seconds += TRACKER_BUFFERING_WOBBLE_SECONDS
         else:
@@ -466,10 +459,8 @@ class BluetoothManager:
             # If the old advertisement is stale, any new advertisement is preferred
             if self._debug:
                 _LOGGER.debug(
-                    (
-                        "%s (%s): Switching from %s to %s (time elapsed:%s > stale"
-                        " seconds:%s)"
-                    ),
+                    "%s (%s): Switching from %s to %s (time elapsed:%s > stale"
+                    " seconds:%s)",
                     new.name,
                     new.address,
                     self._async_describe_source(old),
@@ -485,12 +476,10 @@ class BluetoothManager:
             # the new one is preferred.
             if self._debug:
                 _LOGGER.debug(
-                    (
-                        "%s (%s): Switching from %s to %s (new rssi:%s - threshold:%s >"
-                        " old rssi:%s)"
-                    ),
+                    "%s (%s): Switching from %s to %s (new rssi:%s - threshold:%s >"
+                    " old rssi:%s)",
                     new.name,
-                    address,
+                    new.address,
                     self._async_describe_source(old),
                     self._async_describe_source(new),
                     new.rssi,
@@ -509,13 +498,19 @@ class BluetoothManager:
         # Pre-filter noisy apple devices as they can account for 20-35% of the
         # traffic on a typical network.
         if (
-            len(service_info.manufacturer_data) == 1
-            and not service_info.service_data
+            not service_info.service_data
+            and len(service_info.manufacturer_data) == 1
             and (apple_data := service_info.manufacturer_data.get(APPLE_MFR_ID))
-            is not None
-            and apple_data[0] not in APPLE_START_BYTES_WANTED
         ):
-            return
+            apple_cstr = apple_data
+            if apple_cstr[0] not in {
+                APPLE_IBEACON_START_BYTE,
+                APPLE_HOMEKIT_START_BYTE,
+                APPLE_HOMEKIT_NOTIFY_START_BYTE,
+                APPLE_DEVICE_ID_START_BYTE,
+                APPLE_FINDMY_START_BYTE,
+            }:
+                return
 
         if service_info.connectable:
             old_connectable_service_info = self._connectable_history.get(
@@ -542,11 +537,12 @@ class BluetoothManager:
         if (
             (old_service_info := self._all_history.get(service_info.address))
             is not None
+            and service_info.source is not old_service_info.source
             and service_info.source != old_service_info.source
             and (scanner := self._sources.get(old_service_info.source)) is not None
             and scanner.scanning
             and self._prefer_previous_adv_from_different_source(
-                service_info.address, old_service_info, service_info
+                old_service_info, service_info
             )
         ):
             # If we are rejecting the new advertisement and the device is connectable
@@ -562,7 +558,8 @@ class BluetoothManager:
                     # source, we need to check it as well to see if we prefer
                     # the old connectable advertisement
                     or (
-                        old_connectable_service_info.source != service_info.source
+                        old_connectable_service_info.source is not service_info.source
+                        and old_connectable_service_info.source != service_info.source
                         and (
                             connectable_scanner := self._sources.get(
                                 old_connectable_service_info.source
@@ -571,7 +568,6 @@ class BluetoothManager:
                         is not None
                         and connectable_scanner.scanning
                         and self._prefer_previous_adv_from_different_source(
-                            service_info.address,
                             old_connectable_service_info,
                             service_info,
                         )
@@ -591,8 +587,15 @@ class BluetoothManager:
         # Track advertisement intervals to determine when we need to
         # switch adapters or mark a device as unavailable
         if (
-            last_source := self._advertisement_tracker.sources.get(service_info.address)
-        ) is not None and last_source != service_info.source:
+            (
+                last_source := self._advertisement_tracker.sources.get(
+                    service_info.address
+                )
+            )
+            is not None
+            and last_source is not service_info.source
+            and last_source != service_info.source
+        ):
             # Source changed, remove the old address from the tracker
             self._advertisement_tracker.async_remove_address(service_info.address)
         if service_info.address not in self._advertisement_tracker.intervals:
